#ifndef TIMERSETTINGS_H
#define TIMERSETTINGS_H

#include "fly-date-shared_global.h"

#include <QDateTime>
#include <QObject>
#include <QSharedPointer>

class QSettings;

namespace FlyDate {

struct Timer {
    QString id;
    QString name;
    QString sound;
    QTime   time;
};

class FLYDATESHAREDSHARED_EXPORT TimerSettings : public QObject
{
    Q_OBJECT
    Q_DISABLE_COPY(TimerSettings)

public:
    static TimerSettings* instance();
    ~TimerSettings();

    static QList<Timer> timers(const QString &defaultSoundPath);
    static void removeTimer(const QString &id);
    static void saveTimer(const Timer &timer);

    static QTime currentTime();
    static void setCurrentTime(const QTime &time);

    Q_INVOKABLE static QDateTime timerEndpoint();
    Q_INVOKABLE static void setTimerEndpoint(const QDateTime &dt);

    Q_INVOKABLE static QDateTime timerStartpoint();
    Q_INVOKABLE static void setTimerStartpoint(const QDateTime &dt);

    Q_INVOKABLE static bool isPaused();
    Q_INVOKABLE static void pause(bool p);

    Q_INVOKABLE static QString soundPath();

    static void start(const QTime &ct, const QDateTime &sp, const QDateTime &ep, const QString &sound);
    Q_INVOKABLE static void reset();

private:
    explicit TimerSettings(QObject *parent = nullptr);

    static TimerSettings* m_pinstance;
    static QSharedPointer<QSettings> m_settings;

    struct SettingsGrouper { // TODO make TimerSettings nonstatic?
        SettingsGrouper();
        ~SettingsGrouper();
    };
};
}

#endif // TIMERSETTINGS_H
