import QtQuick 2.5
import Fly.Components 1.0

FlyNotificationItem {
    id: notificationItem

    property bool isPaused: _notification ? _notification.dataMap["pause"] : false

    property real pausedTime: _notification && _notification.dataMap["pausedTime"] ? _notification.dataMap["pausedTime"] : 0
    property real lapsTime: _notification && _notification.dataMap["lapsTime"] ? _notification.dataMap["lapsTime"] : 0
    property real startDate: _notification && _notification.dataMap["startDate"] ? _notification.dataMap["startDate"] : 0

    caption.width: lapTime.x - caption.x - 5
    caption.text: (isPaused ? qsTr("[Paused]") + " " : "") + qsTr("Stopwatch")
    caption.enabled: !isPaused
    description.text: msToTime(pausedTime + lapsTime)

    icon.imagePath: "image://ColorThemeImageProvider/stopwatch"
    icon.imageDesaturateEnabled: isPaused

    function clicked() {
        root.startDetachedProcess("fly-date", ["--show-stopwatch"]);

        return false; // close notification panel
    }

    function parseNotificationData(data) {
        var dataArr = data.split(":");

        if(dataArr.indexOf("pause") >= 0)       isPaused    = _notification.dataMap["pause"];
        if(dataArr.indexOf("pausedTime") >= 0)  pausedTime  = _notification.dataMap["pausedTime"];
        if(dataArr.indexOf("lapsTime") >= 0)    lapsTime    = _notification.dataMap["lapsTime"];
        if(dataArr.indexOf("startDate") >= 0)   startDate   = _notification.dataMap["startDate"];
    }

    function msToTime(duration) {
        var seconds = parseInt((duration / 1000) % 60);
        var minutes = parseInt((duration / (1000 * 60)) % 60);
        var hours   = parseInt((duration / (1000 * 60 * 60)) % 24);

        hours = (hours < 10) ? "0" + hours : hours;
        minutes = (minutes < 10) ? "0" + minutes : minutes;
        seconds = (seconds < 10) ? "0" + seconds : seconds;

        return hours + ":" + minutes + ":" + seconds;
    }

    Connections {
        target: !isPaused ? root : null
        onCurrentDateChanged: {
            description.text = msToTime(Date.now() - startDate + pausedTime + lapsTime);
            lapTime.text = msToTime(Date.now() - startDate + pausedTime);
        }
    }

    FlyLabel {
        id: lapTime
        anchors { top: parent.top; right: parent.right; bottom: parent.bottom; rightMargin: margin }
        text: msToTime(pausedTime)
        font.bold: true
        verticalAlignment: Text.AlignVCenter
    }

    Component.onCompleted: if(_notification) _notification.newData.connect(parseNotificationData);
}
