import QtQuick 2.5
import Fly.Components 1.0
import Fly.Date.Timer 1.0
//import NotificationsBackend 1.0

FlyNotificationItem {
    id: notificationItem

    property var startDate: _notification && _notification.dataMap["startDate"]
                            ? new Date(_notification.dataMap["startDate"]) : null
    property var timerEndpoint: _notification && _notification.dataMap["timerEndpoint"]
                                ? new Date(_notification.dataMap["timerEndpoint"]) : null
    property bool isPaused: _notification ? _notification.dataMap["pause"] : false

    caption.width: datetime.x - caption.x - 5
    caption.text: qsTr("Timer")

    icon.imagePath: "image://ColorThemeImageProvider/timer"
    icon.imageDesaturateEnabled: isPaused

    description.visible: false
    description.y: height * 0.6
    description.height: height * 0.4

    function clicked() {
        root.startDetachedProcess("fly-date", ["--show-timer"]);

        return false; // close notification panel
    }

    function msToTime(duration) {
        var seconds = parseInt((duration / 1000) % 60);
        var minutes = parseInt((duration / (1000 * 60)) % 60);
        var hours   = parseInt((duration / (1000 * 60 * 60)) % 24);

        hours = (hours < 10) ? "0" + hours : hours;
        minutes = (minutes < 10) ? "0" + minutes : minutes;
        seconds = (seconds < 10) ? "0" + seconds : seconds;

        return hours + ":" + minutes + ":" + seconds;
    }

    function parseNotificationData(data) {
        if(data === "resumed") {
            timerEndpoint = new Date(_notification.dataMap["timerEndpoint"]);
        } else if(data === "paused") {
            startDate = new Date(_notification.dataMap["startDate"]);
        }

        isPaused = _notification.dataMap["pause"];
    }

    FlyDateTimeDbusNotifier { id: dbusNotifier }

    FlyLabel {
        id: datetime
        anchors { top: parent.top; right: parent.right; bottom: parent.verticalCenter; rightMargin: margin }
        text: msToTime(timerEndpoint.getTime() -
                       (isPaused
                        ? (startDate ? startDate.getTime() : Date.now())
                        : root.currentDate.getTime()))
        font.pixelSize: description.font.pixelSize;
        verticalAlignment: Text.AlignVCenter
    }

    FlySeparator { x: description.x; y: description.y - height + 1; width: description.width }

    Row {
        id: btnRow
        anchors.fill: description

        readonly property bool isRus: Qt.locale().name.substring(0,2) === "ru"

        // NOTE: currently there is no localization of custom notifications in fly-launcher
        function trString(str) {
            if(!isRus) return str;

            switch (str) {
            case "Resume":  return "Продолжить";
            case "Pause":   return "Пауза";
            case "Stop":    return "Стоп";
            }

            return str;
        }

        FlyMenuButton {
            id: pauseButton
            width: parent.width / 2 - sep.width / 2
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            text: isPaused ? btnRow.trString("Resume") : btnRow.trString("Pause")
            image.imagePath: isPaused
                             ? "image://ThemeImageProvider/media-playback-start"
                             : "image://ThemeImageProvider/media-playback-pause"
            image.imageColorEnabled: true
            image.imageColor: styles.highlightColor
            onClicked: {
                var curDate = new Date;

                if(isPaused) {
                    var dt = new Date(curDate.getTime() + (timerEndpoint.getTime() - startDate.getTime()));

                    TimerSettings.setTimerEndpoint(dt);
                    dbusNotifier.emitTimerResumed("" + dt.getTime());
                } else {
                    startDate = curDate;
                    TimerSettings.setTimerStartpoint(startDate); // updating time
                    dbusNotifier.emitTimerPaused("" + startDate.getTime());
                }

                isPaused = !isPaused;

                TimerSettings.pause(isPaused);
            }
        }

        FlySeparator { id: sep; horizontal: false }

        FlyMenuButton {
            id: stopButton
            width: parent.width / 2 - sep.width / 2
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            text: btnRow.trString("Stop")
            image.imagePath: "image://ThemeImageProvider/media-playback-stop"
            image.imageColorEnabled: true
            image.imageColor: styles.highlightColor
            onClicked: {
                isPaused = true;
                TimerSettings.reset();
                dbusNotifier.emitTimerStopped();
            }
        }
    }

    Component.onCompleted: if(_notification) _notification.newData.connect(parseNotificationData);
}
